import type { AstroConfig } from './@types/astro';
import { z } from 'zod';
export declare const AstroConfigSchema: z.ZodObject<{
    projectRoot: z.ZodEffects<z.ZodDefault<z.ZodOptional<z.ZodString>>, URL>;
    src: z.ZodEffects<z.ZodDefault<z.ZodOptional<z.ZodString>>, URL>;
    pages: z.ZodEffects<z.ZodDefault<z.ZodOptional<z.ZodString>>, URL>;
    public: z.ZodEffects<z.ZodDefault<z.ZodOptional<z.ZodString>>, URL>;
    dist: z.ZodEffects<z.ZodDefault<z.ZodOptional<z.ZodString>>, URL>;
    renderers: z.ZodDefault<z.ZodOptional<z.ZodArray<z.ZodString, "many">>>;
    markdownOptions: z.ZodDefault<z.ZodOptional<z.ZodObject<{
        footnotes: z.ZodOptional<z.ZodBoolean>;
        gfm: z.ZodOptional<z.ZodBoolean>;
        remarkPlugins: z.ZodOptional<z.ZodArray<z.ZodAny, "many">>;
        rehypePlugins: z.ZodOptional<z.ZodArray<z.ZodAny, "many">>;
        render: z.ZodDefault<z.ZodOptional<z.ZodAny>>;
    }, "strip", z.ZodTypeAny, {
        footnotes?: boolean | undefined;
        gfm?: boolean | undefined;
        remarkPlugins?: any[] | undefined;
        rehypePlugins?: any[] | undefined;
        render?: any;
    }, {
        footnotes?: boolean | undefined;
        gfm?: boolean | undefined;
        remarkPlugins?: any[] | undefined;
        rehypePlugins?: any[] | undefined;
        render?: any;
    }>>>;
    buildOptions: z.ZodDefault<z.ZodOptional<z.ZodObject<{
        site: z.ZodOptional<z.ZodString>;
        sitemap: z.ZodDefault<z.ZodOptional<z.ZodBoolean>>;
        pageUrlFormat: z.ZodDefault<z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"file">, z.ZodLiteral<"directory">]>>>;
    }, "strip", z.ZodTypeAny, {
        site?: string | undefined;
        sitemap: boolean;
        pageUrlFormat: "file" | "directory";
    }, {
        site?: string | undefined;
        sitemap?: boolean | undefined;
        pageUrlFormat?: "file" | "directory" | undefined;
    }>>>;
    devOptions: z.ZodDefault<z.ZodOptional<z.ZodObject<{
        hostname: z.ZodDefault<z.ZodOptional<z.ZodString>>;
        port: z.ZodDefault<z.ZodOptional<z.ZodNumber>>;
        tailwindConfig: z.ZodOptional<z.ZodString>;
        trailingSlash: z.ZodDefault<z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"always">, z.ZodLiteral<"never">, z.ZodLiteral<"ignore">]>>>;
    }, "strip", z.ZodTypeAny, {
        tailwindConfig?: string | undefined;
        hostname: string;
        port: number;
        trailingSlash: "always" | "never" | "ignore";
    }, {
        hostname?: string | undefined;
        port?: number | undefined;
        tailwindConfig?: string | undefined;
        trailingSlash?: "always" | "never" | "ignore" | undefined;
    }>>>;
    vite: z.ZodDefault<z.ZodOptional<z.ZodAny>>;
}, "strip", z.ZodTypeAny, {
    vite?: any;
    renderers: string[];
    projectRoot: URL;
    src: URL;
    pages: URL;
    public: URL;
    dist: URL;
    markdownOptions: {
        footnotes?: boolean | undefined;
        gfm?: boolean | undefined;
        remarkPlugins?: any[] | undefined;
        rehypePlugins?: any[] | undefined;
        render?: any;
    };
    buildOptions: {
        site?: string | undefined;
        sitemap: boolean;
        pageUrlFormat: "file" | "directory";
    };
    devOptions: {
        tailwindConfig?: string | undefined;
        hostname: string;
        port: number;
        trailingSlash: "always" | "never" | "ignore";
    };
}, {
    renderers?: string[] | undefined;
    projectRoot?: string | undefined;
    src?: string | undefined;
    pages?: string | undefined;
    public?: string | undefined;
    dist?: string | undefined;
    markdownOptions?: {
        footnotes?: boolean | undefined;
        gfm?: boolean | undefined;
        remarkPlugins?: any[] | undefined;
        rehypePlugins?: any[] | undefined;
        render?: any;
    } | undefined;
    buildOptions?: {
        site?: string | undefined;
        sitemap?: boolean | undefined;
        pageUrlFormat?: "file" | "directory" | undefined;
    } | undefined;
    devOptions?: {
        hostname?: string | undefined;
        port?: number | undefined;
        tailwindConfig?: string | undefined;
        trailingSlash?: "always" | "never" | "ignore" | undefined;
    } | undefined;
    vite?: any;
}>;
/** Turn raw config values into normalized values */
export declare function validateConfig(userConfig: any, root: string): Promise<AstroConfig>;
interface LoadConfigOptions {
    cwd?: string;
    filename?: string;
}
interface LoadConfigOptions {
    cwd?: string;
    filename?: string;
}
/** Attempt to load an `astro.config.mjs` file */
export declare function loadConfig(options: LoadConfigOptions): Promise<AstroConfig>;
export declare function formatConfigError(err: z.ZodError): string;
export {};
