/// <reference types="node" />
import type http from 'http';
import type { AstroConfig } from '../@types/astro';
import type { LogOptions } from '../logger';
import type { HmrContext, ModuleNode } from 'vite';
import connect from 'connect';
export interface DevOptions {
    logging: LogOptions;
}
interface DevServer {
    hostname: string;
    port: number;
    server: connect.Server;
    stop(): Promise<void>;
}
/** `astro dev` */
export default function dev(config: AstroConfig, options?: DevOptions): Promise<DevServer>;
/** Dev server */
export declare class AstroDevServer {
    app: connect.Server;
    httpServer: http.Server | undefined;
    hostname: string;
    port: number;
    private internalCache;
    private config;
    private logging;
    private manifest;
    private origin;
    private routeCache;
    private viteServer;
    private mostRecentRoute?;
    constructor(config: AstroConfig, options: DevOptions);
    /** Start dev server */
    start(): Promise<void>;
    /** Stop dev server */
    stop(): Promise<void>;
    /** Handle HMR */
    handleHotUpdate({ file, modules }: HmrContext): Promise<void | ModuleNode[]>;
    /** Set up Vite server */
    private createViteServer;
    /** The primary router (runs before Vite, in case we need to modify or intercept anything) */
    private handleRequest;
    /** Render error page */
    private renderError;
}
export {};
